==> ejc-technologymanage-api-3.0.0-20230620.015019-31-sources.jar: com/ejianc/business/constructor/vo/ZjlzfaVO.java <==
package com.ejianc.business.constructor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 专家论证方案
 * 
 * @author generator
 * 
 */
public class ZjlzfaVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String famc; // 方案名称
    private Long falxId; // 方案类型id
    private String falxName; // 方案类型
    private Long gcxmmcId; // 工程项目名称id
    private String gcxmmcName; // 工程项目名称
    private Long sgdwId; // 施工单位id
    private String sgdwName; // 施工单位
    private Long gcjdId; // 工程阶段id
    private String gcjdName; // 工程阶段
    private Long gclbId; // 工程类别id
    private String gclbName; // 工程类别
    private Long jglxId; // 结构类型id
    private String jglxName; // 结构类型
    private Long ssxjzId; // 所属巡检组id
    private String ssxjzName; // 所属巡检组
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htkgrq; // 合同开工日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htjgrq; // 合同竣工日期
    private Integer jlsq; // 监理审批(0:是 1：否)
    private String tags; // 分类标签
    private Integer gd; // 是否完成归档(0:是 1：否)
    private String billtype; // 单据类型
    private Long fileid; // 文件id
    private String filename; // 文件名称
    private Long filesize; // 文件大小
    private String filepath; // 文件路径
    private String onlinepath; // 网络路径
    private Long superviseuserid; // 管理人id
    private String superviseusername; // 管理人姓名
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date supervisetime; // 文件上传时间
    private Integer docsource; // 文档来源
    private Long sourceid; // 来源id
    private String orgidfield; // 文件组织名称
    private String projectidfield; // 文件项目名称
    private String detailpageurl; // 页面地址
    private String billcodefield; // 文件单据编号名称
    private String filetype; // 文件类型

    public Integer getGd() {
        return gd;
    }

    public void setGd(Integer gd) {
        this.gd = gd;
    }

    public String getBilltype() {
        return billtype;
    }

    public void setBilltype(String billtype) {
        this.billtype = billtype;
    }

    public Long getFileid() {
        return fileid;
    }

    public void setFileid(Long fileid) {
        this.fileid = fileid;
    }

    public String getFilename() {
        return filename;
    }

    public void setFilename(String filename) {
        this.filename = filename;
    }

    public Long getFilesize() {
        return filesize;
    }

    public void setFilesize(Long filesize) {
        this.filesize = filesize;
    }

    public String getFilepath() {
        return filepath;
    }

    public void setFilepath(String filepath) {
        this.filepath = filepath;
    }

    public String getOnlinepath() {
        return onlinepath;
    }

    public void setOnlinepath(String onlinepath) {
        this.onlinepath = onlinepath;
    }

    public Long getSuperviseuserid() {
        return superviseuserid;
    }

    public void setSuperviseuserid(Long superviseuserid) {
        this.superviseuserid = superviseuserid;
    }

    public String getSuperviseusername() {
        return superviseusername;
    }

    public void setSuperviseusername(String superviseusername) {
        this.superviseusername = superviseusername;
    }

    public Date getSupervisetime() {
        return supervisetime;
    }

    public void setSupervisetime(Date supervisetime) {
        this.supervisetime = supervisetime;
    }

    public Integer getDocsource() {
        return docsource;
    }

    public void setDocsource(Integer docsource) {
        this.docsource = docsource;
    }

    public Long getSourceid() {
        return sourceid;
    }

    public void setSourceid(Long sourceid) {
        this.sourceid = sourceid;
    }

    public String getOrgidfield() {
        return orgidfield;
    }

    public void setOrgidfield(String orgidfield) {
        this.orgidfield = orgidfield;
    }

    public String getProjectidfield() {
        return projectidfield;
    }

    public void setProjectidfield(String projectidfield) {
        this.projectidfield = projectidfield;
    }

    public String getDetailpageurl() {
        return detailpageurl;
    }

    public void setDetailpageurl(String detailpageurl) {
        this.detailpageurl = detailpageurl;
    }

    public String getBillcodefield() {
        return billcodefield;
    }

    public void setBillcodefield(String billcodefield) {
        this.billcodefield = billcodefield;
    }

    public String getFiletype() {
        return filetype;
    }

    public void setFiletype(String filetype) {
        this.filetype = filetype;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }

    @ReferSerialTransfer(referCode = "fazd")
    public Long getFalxId() {
        return falxId;
    }
    @ReferDeserialTransfer
    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    @ReferSerialTransfer(referCode = "project-set")

    public Long getGcxmmcId() {
        return gcxmmcId;
    }
    @ReferDeserialTransfer
    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getGcjdId() {
        return gcjdId;
    }

    public void setGcjdId(Long gcjdId) {
        this.gcjdId = gcjdId;
    }
    public String getGcjdName() {
        return gcjdName;
    }

    public void setGcjdName(String gcjdName) {
        this.gcjdName = gcjdName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getGclbId() {
        return gclbId;
    }
    @ReferDeserialTransfer
    public void setGclbId(Long gclbId) {
        this.gclbId = gclbId;
    }
    public String getGclbName() {
        return gclbName;
    }

    public void setGclbName(String gclbName) {
        this.gclbName = gclbName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getJglxId() {
        return jglxId;
    }
    @ReferDeserialTransfer
    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSsxjzId() {
        return ssxjzId;
    }
    @ReferDeserialTransfer
    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getHtkgrq() {
        return htkgrq;
    }

    public void setHtkgrq(Date htkgrq) {
        this.htkgrq = htkgrq;
    }
    public Date getHtjgrq() {
        return htjgrq;
    }

    public void setHtjgrq(Date htjgrq) {
        this.htjgrq = htjgrq;
    }
    public Integer getJlsq() {
        return jlsq;
    }

    public void setJlsq(Integer jlsq) {
        this.jlsq = jlsq;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }
}

==> ejc-technologymanage-api-3.0.0-20241213.082939-48-sources.jar: com/ejianc/business/constructor/vo/ZjlzfaVO.java <==
package com.ejianc.business.constructor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 专家论证方案
 * 
 * @author generator
 * 
 */
public class ZjlzfaVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String famc; // 方案名称
    private Long falxId; // 方案类型id
    private String falxName; // 方案类型
    private Long gcxmmcId; // 工程项目名称id
    private String gcxmmcName; // 工程项目名称
    private Long sgdwId; // 施工单位id
    private String sgdwName; // 施工单位
    private Long gcjdId; // 工程阶段id
    private String gcjdName; // 工程阶段
    private Long gclbId; // 工程类别id
    private String gclbName; // 工程类别
    private Long jglxId; // 结构类型id
    private String jglxName; // 结构类型
    private Long ssxjzId; // 所属巡检组id
    private String ssxjzName; // 所属巡检组
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htkgrq; // 合同开工日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htjgrq; // 合同竣工日期
    private Integer jlsq; // 监理审批(0:是 1：否)
    private String tags; // 分类标签
    private Integer gd; // 是否完成归档(0:是 1：否)
    private String billtype; // 单据类型
    private Long fileid; // 文件id
    private String filename; // 文件名称
    private Long filesize; // 文件大小
    private String filepath; // 文件路径
    private String onlinepath; // 网络路径
    private Long superviseuserid; // 管理人id
    private String superviseusername; // 管理人姓名
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date supervisetime; // 文件上传时间
    private Integer docsource; // 文档来源
    private Long sourceid; // 来源id
    private String orgidfield; // 文件组织名称
    private String projectidfield; // 文件项目名称
    private String detailpageurl; // 页面地址
    private String billcodefield; // 文件单据编号名称
    private String filetype; // 文件类型
    private String jlsqName; // 监理审批(0:是 1：否)
    private String gdName; // 是否完成归档(0:是 1：否)
    private String docsourceName; // 文档来源
    public Integer getGd() {
        return gd;
    }

    public void setGd(Integer gd) {
        this.gd = gd;
    }

    public String getBilltype() {
        return billtype;
    }

    public void setBilltype(String billtype) {
        this.billtype = billtype;
    }

    public Long getFileid() {
        return fileid;
    }

    public void setFileid(Long fileid) {
        this.fileid = fileid;
    }

    public String getFilename() {
        return filename;
    }

    public void setFilename(String filename) {
        this.filename = filename;
    }

    public Long getFilesize() {
        return filesize;
    }

    public void setFilesize(Long filesize) {
        this.filesize = filesize;
    }

    public String getFilepath() {
        return filepath;
    }

    public void setFilepath(String filepath) {
        this.filepath = filepath;
    }

    public String getOnlinepath() {
        return onlinepath;
    }

    public void setOnlinepath(String onlinepath) {
        this.onlinepath = onlinepath;
    }

    public Long getSuperviseuserid() {
        return superviseuserid;
    }

    public void setSuperviseuserid(Long superviseuserid) {
        this.superviseuserid = superviseuserid;
    }

    public String getSuperviseusername() {
        return superviseusername;
    }

    public void setSuperviseusername(String superviseusername) {
        this.superviseusername = superviseusername;
    }

    public Date getSupervisetime() {
        return supervisetime;
    }

    public void setSupervisetime(Date supervisetime) {
        this.supervisetime = supervisetime;
    }

    public Integer getDocsource() {
        return docsource;
    }

    public void setDocsource(Integer docsource) {
        this.docsource = docsource;
    }

    public Long getSourceid() {
        return sourceid;
    }

    public void setSourceid(Long sourceid) {
        this.sourceid = sourceid;
    }

    public String getOrgidfield() {
        return orgidfield;
    }

    public void setOrgidfield(String orgidfield) {
        this.orgidfield = orgidfield;
    }

    public String getProjectidfield() {
        return projectidfield;
    }

    public void setProjectidfield(String projectidfield) {
        this.projectidfield = projectidfield;
    }

    public String getDetailpageurl() {
        return detailpageurl;
    }

    public void setDetailpageurl(String detailpageurl) {
        this.detailpageurl = detailpageurl;
    }

    public String getBillcodefield() {
        return billcodefield;
    }

    public void setBillcodefield(String billcodefield) {
        this.billcodefield = billcodefield;
    }

    public String getFiletype() {
        return filetype;
    }

    public void setFiletype(String filetype) {
        this.filetype = filetype;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }

    @ReferSerialTransfer(referCode = "fazd")
    public Long getFalxId() {
        return falxId;
    }
    @ReferDeserialTransfer
    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    @ReferSerialTransfer(referCode = "project-set")

    public Long getGcxmmcId() {
        return gcxmmcId;
    }
    @ReferDeserialTransfer
    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getGcjdId() {
        return gcjdId;
    }

    public void setGcjdId(Long gcjdId) {
        this.gcjdId = gcjdId;
    }
    public String getGcjdName() {
        return gcjdName;
    }

    public void setGcjdName(String gcjdName) {
        this.gcjdName = gcjdName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getGclbId() {
        return gclbId;
    }
    @ReferDeserialTransfer
    public void setGclbId(Long gclbId) {
        this.gclbId = gclbId;
    }
    public String getGclbName() {
        return gclbName;
    }

    public void setGclbName(String gclbName) {
        this.gclbName = gclbName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getJglxId() {
        return jglxId;
    }
    @ReferDeserialTransfer
    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSsxjzId() {
        return ssxjzId;
    }
    @ReferDeserialTransfer
    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getHtkgrq() {
        return htkgrq;
    }

    public void setHtkgrq(Date htkgrq) {
        this.htkgrq = htkgrq;
    }
    public Date getHtjgrq() {
        return htjgrq;
    }

    public void setHtjgrq(Date htjgrq) {
        this.htjgrq = htjgrq;
    }
    public Integer getJlsq() {
        return jlsq;
    }

    public void setJlsq(Integer jlsq) {
        this.jlsq = jlsq;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }


    public String getJlsqName() {
        return jlsqName;
    }

    public void setJlsqName(String jlsqName) {
        this.jlsqName = jlsqName;
    }

    public String getGdName() {
        return gdName;
    }

    public void setGdName(String gdName) {
        this.gdName = gdName;
    }

    public String getDocsourceName() {
        return docsourceName;
    }

    public void setDocsourceName(String docsourceName) {
        this.docsourceName = docsourceName;
    }
}
